@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,94 +18,17 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkrds.endpoint import endpoint_data
+
 class AddTagsToResourceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'AddTagsToResource')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'AddTagsToResource','rds')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_ResourceOwnerAccount(self):
-		return self.get_query_params().get('ResourceOwnerAccount')
-
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_ResourceOwnerId(self):
-		return self.get_query_params().get('ResourceOwnerId')
-
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ClientToken(self):
-		return self.get_query_params().get('ClientToken')
-
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_proxyId(self):
-		return self.get_query_params().get('proxyId')
-
-	def set_proxyId(self,proxyId):
-		self.add_query_param('proxyId',proxyId)
-
-	def get_DBInstanceId(self):
-		return self.get_query_params().get('DBInstanceId')
-
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_Tag1key(self):
-		return self.get_query_params().get('Tag.1.key')
-
-	def set_Tag1key(self,Tag1key):
-		self.add_query_param('Tag.1.key',Tag1key)
-
-	def get_Tag2key(self):
-		return self.get_query_params().get('Tag.2.key')
-
-	def set_Tag2key(self,Tag2key):
-		self.add_query_param('Tag.2.key',Tag2key)
-
-	def get_Tag3key(self):
-		return self.get_query_params().get('Tag.3.key')
-
-	def set_Tag3key(self,Tag3key):
-		self.add_query_param('Tag.3.key',Tag3key)
-
-	def get_Tag4key(self):
-		return self.get_query_params().get('Tag.4.key')
-
-	def set_Tag4key(self,Tag4key):
-		self.add_query_param('Tag.4.key',Tag4key)
-
-	def get_Tag5key(self):
-		return self.get_query_params().get('Tag.5.key')
-
-	def set_Tag5key(self,Tag5key):
-		self.add_query_param('Tag.5.key',Tag5key)
-
-	def get_Tag1value(self):
-		return self.get_query_params().get('Tag.1.value')
-
-	def set_Tag1value(self,Tag1value):
-		self.add_query_param('Tag.1.value',Tag1value)
-
-	def get_Tag2value(self):
-		return self.get_query_params().get('Tag.2.value')
-
-	def set_Tag2value(self,Tag2value):
-		self.add_query_param('Tag.2.value',Tag2value)
-
-	def get_Tag3value(self):
-		return self.get_query_params().get('Tag.3.value')
-
-	def set_Tag3value(self,Tag3value):
-		self.add_query_param('Tag.3.value',Tag3value)
 
 	def get_Tag4value(self):
 		return self.get_query_params().get('Tag.4.value')
@@ -113,14 +36,104 @@ class AddTagsToResourceRequest(RpcRequest):
 	def set_Tag4value(self,Tag4value):
 		self.add_query_param('Tag.4.value',Tag4value)
 
+	def get_ResourceOwnerId(self):
+		return self.get_query_params().get('ResourceOwnerId')
+
+	def set_ResourceOwnerId(self,ResourceOwnerId):
+		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+
+	def get_Tag2key(self):
+		return self.get_query_params().get('Tag.2.key')
+
+	def set_Tag2key(self,Tag2key):
+		self.add_query_param('Tag.2.key',Tag2key)
+
+	def get_ClientToken(self):
+		return self.get_query_params().get('ClientToken')
+
+	def set_ClientToken(self,ClientToken):
+		self.add_query_param('ClientToken',ClientToken)
+
+	def get_Tag3key(self):
+		return self.get_query_params().get('Tag.3.key')
+
+	def set_Tag3key(self,Tag3key):
+		self.add_query_param('Tag.3.key',Tag3key)
+
+	def get_Tag1value(self):
+		return self.get_query_params().get('Tag.1.value')
+
+	def set_Tag1value(self,Tag1value):
+		self.add_query_param('Tag.1.value',Tag1value)
+
+	def get_DBInstanceId(self):
+		return self.get_query_params().get('DBInstanceId')
+
+	def set_DBInstanceId(self,DBInstanceId):
+		self.add_query_param('DBInstanceId',DBInstanceId)
+
+	def get_Tag3value(self):
+		return self.get_query_params().get('Tag.3.value')
+
+	def set_Tag3value(self,Tag3value):
+		self.add_query_param('Tag.3.value',Tag3value)
+
+	def get_proxyId(self):
+		return self.get_query_params().get('proxyId')
+
+	def set_proxyId(self,proxyId):
+		self.add_query_param('proxyId',proxyId)
+
+	def get_Tag5key(self):
+		return self.get_query_params().get('Tag.5.key')
+
+	def set_Tag5key(self,Tag5key):
+		self.add_query_param('Tag.5.key',Tag5key)
+
+	def get_ResourceOwnerAccount(self):
+		return self.get_query_params().get('ResourceOwnerAccount')
+
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+
+	def get_OwnerAccount(self):
+		return self.get_query_params().get('OwnerAccount')
+
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
 	def get_Tag5value(self):
 		return self.get_query_params().get('Tag.5.value')
 
 	def set_Tag5value(self,Tag5value):
 		self.add_query_param('Tag.5.value',Tag5value)
 
-	def get_OwnerAccount(self):
-		return self.get_query_params().get('OwnerAccount')
+	def get_Tags(self):
+		return self.get_query_params().get('Tags')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
\ No newline at end of file
+	def set_Tags(self,Tags):
+		self.add_query_param('Tags',Tags)
+
+	def get_Tag1key(self):
+		return self.get_query_params().get('Tag.1.key')
+
+	def set_Tag1key(self,Tag1key):
+		self.add_query_param('Tag.1.key',Tag1key)
+
+	def get_Tag2value(self):
+		return self.get_query_params().get('Tag.2.value')
+
+	def set_Tag2value(self,Tag2value):
+		self.add_query_param('Tag.2.value',Tag2value)
+
+	def get_Tag4key(self):
+		return self.get_query_params().get('Tag.4.key')
+
+	def set_Tag4key(self,Tag4key):
+		self.add_query_param('Tag.4.key',Tag4key)
\ No newline at end of file
