@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,22 +18,17 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkrds.endpoint import endpoint_data
+
 class DescribeDBInstancesByExpireTimeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescribeDBInstancesByExpireTime')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'DescribeDBInstancesByExpireTime','rds')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_ResourceOwnerAccount(self):
-		return self.get_query_params().get('ResourceOwnerAccount')
-
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
 
 	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
@@ -41,23 +36,17 @@ class DescribeDBInstancesByExpireTimeRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
-	def get_ClientToken(self):
-		return self.get_query_params().get('ClientToken')
+	def get_PageNumber(self):
+		return self.get_query_params().get('PageNumber')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
+	def set_PageNumber(self,PageNumber):
+		self.add_query_param('PageNumber',PageNumber)
 
-	def get_proxyId(self):
-		return self.get_query_params().get('proxyId')
+	def get_Expired(self):
+		return self.get_query_params().get('Expired')
 
-	def set_proxyId(self,proxyId):
-		self.add_query_param('proxyId',proxyId)
-
-	def get_ExpirePeriod(self):
-		return self.get_query_params().get('ExpirePeriod')
-
-	def set_ExpirePeriod(self,ExpirePeriod):
-		self.add_query_param('ExpirePeriod',ExpirePeriod)
+	def set_Expired(self,Expired):
+		self.add_query_param('Expired',Expired)
 
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
@@ -65,14 +54,38 @@ class DescribeDBInstancesByExpireTimeRequest(RpcRequest):
 	def set_PageSize(self,PageSize):
 		self.add_query_param('PageSize',PageSize)
 
-	def get_PageNumber(self):
-		return self.get_query_params().get('PageNumber')
+	def get_ExpirePeriod(self):
+		return self.get_query_params().get('ExpirePeriod')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
+	def set_ExpirePeriod(self,ExpirePeriod):
+		self.add_query_param('ExpirePeriod',ExpirePeriod)
+
+	def get_proxyId(self):
+		return self.get_query_params().get('proxyId')
+
+	def set_proxyId(self,proxyId):
+		self.add_query_param('proxyId',proxyId)
+
+	def get_ResourceOwnerAccount(self):
+		return self.get_query_params().get('ResourceOwnerAccount')
+
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
 
 	def get_OwnerAccount(self):
 		return self.get_query_params().get('OwnerAccount')
 
 	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
\ No newline at end of file
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
+	def get_Tags(self):
+		return self.get_query_params().get('Tags')
+
+	def set_Tags(self,Tags):
+		self.add_query_param('Tags',Tags)
\ No newline at end of file
