@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,22 +18,23 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkrds.endpoint import endpoint_data
+
 class ModifySecurityIpsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifySecurityIps')
+		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'ModifySecurityIps','rds')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
+	def get_DBInstanceIPArrayName(self):
+		return self.get_query_params().get('DBInstanceIPArrayName')
 
-	def get_ResourceOwnerAccount(self):
-		return self.get_query_params().get('ResourceOwnerAccount')
-
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+	def set_DBInstanceIPArrayName(self,DBInstanceIPArrayName):
+		self.add_query_param('DBInstanceIPArrayName',DBInstanceIPArrayName)
 
 	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
@@ -41,11 +42,23 @@ class ModifySecurityIpsRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
-	def get_ClientToken(self):
-		return self.get_query_params().get('ClientToken')
+	def get_SecurityIps(self):
+		return self.get_query_params().get('SecurityIps')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
+	def set_SecurityIps(self,SecurityIps):
+		self.add_query_param('SecurityIps',SecurityIps)
+
+	def get_WhitelistNetworkType(self):
+		return self.get_query_params().get('WhitelistNetworkType')
+
+	def set_WhitelistNetworkType(self,WhitelistNetworkType):
+		self.add_query_param('WhitelistNetworkType',WhitelistNetworkType)
+
+	def get_SecurityIPType(self):
+		return self.get_query_params().get('SecurityIPType')
+
+	def set_SecurityIPType(self,SecurityIPType):
+		self.add_query_param('SecurityIPType',SecurityIPType)
 
 	def get_DBInstanceId(self):
 		return self.get_query_params().get('DBInstanceId')
@@ -53,14 +66,14 @@ class ModifySecurityIpsRequest(RpcRequest):
 	def set_DBInstanceId(self,DBInstanceId):
 		self.add_query_param('DBInstanceId',DBInstanceId)
 
-	def get_SecurityIps(self):
-		return self.get_query_params().get('SecurityIps')
+	def get_ModifyMode(self):
+		return self.get_query_params().get('ModifyMode')
 
-	def set_SecurityIps(self,SecurityIps):
-		self.add_query_param('SecurityIps',SecurityIps)
+	def set_ModifyMode(self,ModifyMode):
+		self.add_query_param('ModifyMode',ModifyMode)
 
-	def get_OwnerAccount(self):
-		return self.get_query_params().get('OwnerAccount')
+	def get_DBInstanceIPArrayAttribute(self):
+		return self.get_query_params().get('DBInstanceIPArrayAttribute')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
\ No newline at end of file
+	def set_DBInstanceIPArrayAttribute(self,DBInstanceIPArrayAttribute):
+		self.add_query_param('DBInstanceIPArrayAttribute',DBInstanceIPArrayAttribute)
\ No newline at end of file
